@@ -8,10 +8,8 @@ use DBIx::Custom::Util '_subname';
 # Carp trust relationship
 push @DBIx::Custom::CARP_NOT, __PACKAGE__;
 
-has [qw/dbi name table view/],
-    table_alias => sub { {} },
+has [qw/dbi table/],
     columns => sub { [] },
-    filter => sub { [] },
     join => sub { [] },
     type => sub { [] },
     primary_key => sub { [] };
@@ -64,23 +62,6 @@ foreach my $method (@methods) {
     *{"${class}::$method"} = $code;
 }
 
-sub column {
-    my ($self, $table, $columns) = @_;
-    
-    $self->{_table_alias} ||= {};
-    my $dist;
-    $dist = $self->dbi->{_table_alias}{$table}
-          ? $self->dbi->{_table_alias}{$table}
-          : $table;
-    
-    $self->dbi->{_model_from} ||= {};
-    my $model = $self->dbi->{_model_from}->{$dist};
-    
-    $columns ||= $self->model($model)->columns;
-    
-    return $self->dbi->column($table, $columns);
-}
-
 sub DESTROY { }
 
 sub method {
@@ -117,6 +98,10 @@ sub new {
     return $self;
 }
 
+# DEPRECATED!
+has filter => sub { [] };
+has 'name';
+
 1;
 
 =head1 NAME
@@ -138,23 +123,6 @@ my $table = DBIx::Custom::Model->new(table => 'books');
 
 L<DBIx::Custom> object.
 
-=head2 C<filter>
-
-    my $dbi = $model->filter
-    $model  = $model->filter(
-        title => {out => 'tp_to_date', in => 'date_to_tp'}
-        author => {out => ..., in => ...},
-    );
-
-This filter is applied when L<DBIx::Custom>'s C<include_model()> is called.
-
-=head2 C<name>
-
-    my $name = $model->name;
-    $model   = $model->name('book');
-
-Model name.
-
 =head2 C<join>
 
     my $join = $model->join;
@@ -180,15 +148,6 @@ C<delete_at()>,C<select_at()>.
 Table name, this is used as C<select()> C<table> option.
 Generally, this is automatically set from class name.
 
-=head2 C<table_alias> EXPERIMENTAL
-
-    my $table_alias = $model->table_alias;
-    $model = $model->table_alias(user1 => 'user', user2 => 'user');
-
-Table alias. If you define table alias,
-same filter as the table is avaliable
-, and can write $dbi->column('user1') to get all columns.
-
 =head2 C<type>
 
     my $type = $model->type;
@@ -198,32 +157,12 @@ Database data type, this is used as type optioon of C<insert()>, C<insert_at()>,
 C<update()>, C<update_at()>, C<update_all>, C<delete()>, C<delete_all()>,
 C<select()>, C<select_at()>
 
-=head2 C<view>
-
-    my $view = $model->view;
-    $model   = $model->view('select id, DATE(issue_datetime) as date from book');
-
-View. This view is registered by C<view()> of L<DBIx::Custom> when
-model is included by C<include_model>.
-
 =head1 METHODS
 
-L<DBIx::Custom> inherits all methods from L<Object::Simple>,
-and you can use all methods of the object set to C<dbi>.
+L<DBIx::Custom::Model> inherits all methods from L<Object::Simple>,
+and you can use all methods of L<DBIx::Custom> and L<DBI>
 and implements the following new ones.
 
-=head2 C<column> EXPERIMETNAL
-
-    my $column = $model->column(book => ['author', 'title']);
-    my $column = $model->column('book');
-
-Create column clause. The follwoing column clause is created.
-
-    book.author as "book.author",
-    book.title as "book.title"
-
-If Second argument is ommited, all columns set by C<columns> is used.
-
 =head2 C<delete>
 
     $table->delete(...);
@@ -305,30 +244,4 @@ you don't have to specify C<table> option.
 Same as C<update_all()> of L<DBIx::Custom> except that
 you don't have to specify table name.
 
-=head2 C<update_at> DEPRECATED!
-
-    $table->update_at(...);
-    
-Same as C<update_at()> of L<DBIx::Custom> except that
-you don't have to specify C<table> and C<primary_key> option.
-
-=head2 C<select_at> DEPRECATED!
-
-    $table->select_at(...);
-    
-Same as C<select_at()> of L<DBIx::Custom> except that
-you don't have to specify C<table> and C<primary_key> option.
-
-=head2 C<insert_at> DEPRECATED!
-
-    $table->insert_at(...);
-    
-Same as C<insert_at()> of L<DBIx::Custom> except that
-you don't have to specify C<table> and C<primary_key> option.
-
-=head2 C<delete_at> DEPRECATED!
-
-    $table->delete_at(...);
-    
-Same as C<delete()> of L<DBIx::Custom> except that
-you don't have to specify C<table> and C<primary_key> option.
+=cut
